==> miredo_1.1.3.orig.tar.gz: miredo-1.1.3/autogen.sh <==
#!/bin/sh
# SVN package rebuild script
# $Id: autogen.sh 1947 2007-04-12 15:26:58Z remi $
#
# ***********************************************************************
# *  Copyright © 2002-2005 Rémi Denis-Courmont.                         *
# *  This program is free software; you can redistribute and/or modify  *
# *  it under the terms of the GNU General Public License as published  *
# *  by the Free Software Foundation; version 2 of the license.         *
# *                                                                     *
# *  This program is distributed in the hope that it will be useful,    *
# *  but WITHOUT ANY WARRANTY; without even the implied warranty of     *
# *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               *
# *  See the GNU General Public License for more details.               *
# *                                                                     *
# *  You should have received a copy of the GNU General Public License  *
# *  along with this program; if not, you can get it from:              *
# *  http://www.gnu.org/copyleft/gpl.html                               *
# ***********************************************************************

set -xe

if test -f doc/miredo.8-in ; then
	true
elif test -f ../doc/miredo.8-in; then
	cd ..
else
	echo "You must run this script from your miredo SVN directory."
	false
fi

echo "Autoreconf in $PWD ..."

autoreconf -sfi
unlink po/Makevars.template

for d in /usr /usr/local /opt/gettext /usr/pkg "$HOME"; do
	if test -f "$d/share/gettext/gettext.h" ; then
		ln -sf "$d/share/gettext/gettext.h" include/gettext.h
	fi
done

set +x

test -f "include/gettext.h" || {
echo "Error: can't find <gettext.h> convenience C header."
echo "Please put a link to it by hand as include/gettext.h"
exit 1
}

echo ""
echo "Type \`./configure' to configure the package for your system"
echo "(type \`./configure -- help' for help)."
echo "Then you can use the usual \`make', \`make install', etc."

==> miredo_1.1.5.orig.tar.gz: miredo-1.1.5/autogen.sh <==
#!/bin/sh
# SVN package rebuild script
# $Id: autogen.sh 2096 2008-01-05 18:08:54Z remi $
#
# ***********************************************************************
# *  Copyright © 2002-2005 Rémi Denis-Courmont.                         *
# *  This program is free software; you can redistribute and/or modify  *
# *  it under the terms of the GNU General Public License as published  *
# *  by the Free Software Foundation; version 2 of the license.         *
# *                                                                     *
# *  This program is distributed in the hope that it will be useful,    *
# *  but WITHOUT ANY WARRANTY; without even the implied warranty of     *
# *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               *
# *  See the GNU General Public License for more details.               *
# *                                                                     *
# *  You should have received a copy of the GNU General Public License  *
# *  along with this program; if not, you can get it from:              *
# *  http://www.gnu.org/copyleft/gpl.html                               *
# ***********************************************************************

set -xe

if test -f doc/miredo.8-in ; then
	true
elif test -f ../doc/miredo.8-in; then
	cd ..
else
	echo "You must run this script from your miredo SVN directory."
	false
fi

echo "Autoreconf in $PWD ..."

autoreconf -sfi
unlink po/Makevars.template

for d in /usr /usr/local /opt/gettext /opt/local/share/gettext \
		/usr/pkg "$HOME"; do
	if test -f "$d/share/gettext/gettext.h" ; then
		ln -sf "$d/share/gettext/gettext.h" include/gettext.h
	fi
done

set +x

test -f "include/gettext.h" || {
echo "Error: can't find <gettext.h> convenience C header."
echo "Please put a link to it by hand as include/gettext.h"
exit 1
}

echo ""
echo "Type \`./configure' to configure the package for your system"
echo "(type \`./configure -- help' for help)."
echo "Then you can use the usual \`make', \`make install', etc."
